==> typhoon-0.1.0.tgz: package/lib/typhoon/articleController.js <==
var Article, Helpers, View, app, fs, haml, path;
fs = require('fs');
View = require('./view').View;
Helpers = require('./view').Helpers;
Article = require('./article').Article;
haml = require('hamljs');
path = require('path');
require('./patches');
/*
Init app and setup routes
*/
app = function(configs) {
  var articleView, feedView, getArticles, listView, _ref, _ref2, _ref3;
  configs != null ? configs : configs = {};
  (_ref = configs.perPage) != null ? _ref : configs.perPage = 10;
  (_ref2 = configs.ext) != null ? _ref2 : configs.ext = '.txt';
  (_ref3 = configs.encoding) != null ? _ref3 : configs.encoding = 'utf8';
  Article.baseUrl(configs.baseUrl);
  View.templatesDir(configs.templatesDir);
  View.globals({
    configs: configs
  });
  articleView = new View('/article.haml', configs.encoding);
  listView = new View('/list.haml', configs.encoding);
  feedView = new View(__dirname + '/feed.haml', configs.encoding, {
    xml: true
  }, true);
  getArticles = function(filter, page, perPage, callback) {
    var limit, offset;
    if (page == null) {
      page = 1;
    }
    if (perPage == null) {
      perPage = 15;
    }
    limit = perPage;
    offset = page * perPage - perPage;
    return fs.readdir(configs.articlesDir, function(err, files) {
      var articles, i, loadArticles;
      if (err) {
        return callback(err);
      }
      articles = [];
      filter || (filter = (function() {
        return true;
      }));
      files = files.filter(filter).sort().reverse();
      i = 0;
      loadArticles = function(done) {
        var file;
        i++;
        file = files.shift();
        if ((i - 1) < offset) {
          return loadArticles(done);
        }
        if (!file) {
          return done(false);
        }
        if (articles.length === limit) {
          return done(file || files.length > 0);
        }
        Article.fromFile(configs.articlesDir + '/' + file, configs.encoding, function(err, article) {
          if (!err) {
            articles.push(article);
          }
          return loadArticles(done);
        });
      };
      return loadArticles(function(hasMore) {
        return callback(null, articles, hasMore);
      });
    });
  };
  return function(app) {
    app.get(/^(?:(?:\/([0-9]{4})(?:\/([0-9]{2})(?:\/([0-9]{2}))?)?)?)(?:\/?page\/([0-9]+))?\/?$/, function(req, res, next) {
      var filter, filterDay, filterMonth, filterPage, filterParams, filterPattern, filterYear, locals, _ref;
      locals = {
        articles: []
      };
      _ref = req.params, filterYear = _ref[0], filterMonth = _ref[1], filterDay = _ref[2], filterPage = _ref[3];
      filterParams = [filterYear, filterMonth, filterDay].filter(function(v) {
        return typeof v !== 'undefined';
      });
      if (filterParams.length > 0) {
        filterPattern = new RegExp('^' + filterParams.join('-'));
        filter = function(file) {
          return file.match(filterPattern);
        };
      }
      filterPage || (filterPage = 1);
      return getArticles(filter, filterPage, configs.perPage, function(err, articles, hasMore) {
        var pageLink;
        if (filterParams.length > 0) {
          locals.action = 'archives';
          if (filterDay) {
            locals.archivesType = 'Daily';
            locals.archivesLabel = new Date(Date.UTC(filterYear, filterMonth - 1, filterDay)).pretty();
          } else if (filterMonth) {
            locals.archivesType = 'Monthly';
            locals.archivesLabel = Date.prototype.months[filterMonth - 1] + ' ' + filterYear;
          } else {
            locals.archivesType = 'Yearly';
            locals.archivesLabel = filterYear;
          }
        } else {
          locals.action = 'listing';
        }
        locals.articles = articles;
        locals.page = parseInt(filterPage);
        locals.filter = filterParams;
        locals.paging = {};
        pageLink = function(page) {
          var url;
          url = configs.baseUrl + '/' + filterParams.join('/');
          if (page > 1) {
            url = url + 'page/' + page;
          }
          return url;
        };
        if (locals.page > 1) {
          locals.paging.previous = pageLink(locals.page - 1);
        }
        if (hasMore) {
          locals.paging.next = pageLink(locals.page + 1);
        }
        return listView.render(res, locals, function(err) {
          if (err) {
            return next(new Error(500, err));
          }
        });
      });
    });
    app.get(/^\/([0-9]{4})\/([0-9]{2})\/([0-9]{2})\/(.*)\/?$/, function(req, res, next) {
      return Article.fromFile(configs.articlesDir + '/' + path.normalize(req.params.join('-')) + configs.ext, configs.encoding, function(err, article) {
        var locals;
        if (err) {
          return next(new Error(404, err));
        }
        locals = {
          article: article
        };
        return articleView.render(res, locals, function(err) {
          if (err) {
            return next(new Error(500, err));
          }
        });
      });
    });
    return app.get('/feed.xml', function(req, res, next) {
      return getArticles(null, 1, 25, function(err, articles) {
        var locals;
        if (err) {
          return next(new Error(500, err));
        }
        locals = {
          articles: articles,
          lastBuild: new Date()
        };
        return feedView.partial(locals, function(err, data) {
          if (err) {
            return next(new Error(500, err));
          }
          res.writeHead(200, {
            'content-type': 'text/xml'
          });
          return res.end(data);
        });
      });
    });
  };
};
/*
Module Exports
*/
exports.app = app;

==> typhoon-0.1.2.tgz: package/lib/typhoon/articleController.js <==
var Article, Helpers, View, app, fs, haml, path;
fs = require('fs');
View = require('./view').View;
Helpers = require('./view').Helpers;
Article = require('./article').Article;
haml = require('hamljs');
path = require('path');
require('./patches');
/*
Init app and setup routes
*/
app = function(configs) {
  var articleView, feedView, getArticles, listView, _ref, _ref2, _ref3;
  configs != null ? configs : configs = {};
  (_ref = configs.perPage) != null ? _ref : configs.perPage = 10;
  (_ref2 = configs.ext) != null ? _ref2 : configs.ext = '.txt';
  (_ref3 = configs.encoding) != null ? _ref3 : configs.encoding = 'utf8';
  Article.baseUrl(configs.baseUrl);
  View.templatesDir(configs.templatesDir);
  View.globals({
    configs: configs
  });
  articleView = new View('/article.haml', configs.encoding);
  listView = new View('/list.haml', configs.encoding);
  feedView = new View(__dirname + '/feed.haml', configs.encoding, {
    xml: true
  }, true);
  getArticles = function(filter, page, perPage, callback) {
    var limit, offset;
    if (page == null) {
      page = 1;
    }
    if (perPage == null) {
      perPage = 15;
    }
    limit = perPage;
    offset = page * perPage - perPage;
    return fs.readdir(configs.articlesDir, function(err, files) {
      var articles, i, loadArticles;
      if (err) {
        return callback(err);
      }
      articles = [];
      filter || (filter = (function() {
        return true;
      }));
      files = files.filter(filter).sort().reverse();
      i = 0;
      loadArticles = function(done) {
        var file;
        i++;
        file = files.shift();
        if ((i - 1) < offset) {
          return loadArticles(done);
        }
        if (!file) {
          return done(false);
        }
        if (articles.length === limit) {
          return done(file || files.length > 0);
        }
        Article.fromFile(configs.articlesDir + '/' + file, configs.encoding, function(err, article) {
          if (!err) {
            articles.push(article);
          }
          return loadArticles(done);
        });
      };
      return loadArticles(function(hasMore) {
        return callback(null, articles, hasMore);
      });
    });
  };
  return function(app) {
    app.get(/^(?:(?:\/([0-9]{4})(?:\/([0-9]{2})(?:\/([0-9]{2}))?)?)?)(?:\/?page\/([0-9]+))?\/?$/, function(req, res, next) {
      var filter, filterDay, filterMonth, filterPage, filterParams, filterPattern, filterYear, locals, validateDate, _ref;
      locals = {
        articles: []
      };
      _ref = req.params, filterYear = _ref[0], filterMonth = _ref[1], filterDay = _ref[2], filterPage = _ref[3];
      filterParams = [filterYear, filterMonth, filterDay].filter(function(v) {
        return typeof v !== 'undefined';
      });
      validateDate = function(year, month, day) {
        var date;
        year || (year = 2011);
        month || (month = 1);
        day || (day = 1);
        date = new Date(Date.UTC(year, month - 1, day));
        return date.getUTCFullYear() === parseInt(year) && date.getUTCMonth() + 1 === parseInt(month) && date.getUTCDate() === parseInt(day);
      };
      if (!validateDate(filterYear, filterMonth, filterDay)) {
        return next(new Error(404));
      }
      if (filterParams.length > 0) {
        filterPattern = new RegExp('^' + filterParams.join('-'));
        filter = function(file) {
          return file.match(filterPattern);
        };
      }
      filterPage || (filterPage = 1);
      return getArticles(filter, filterPage, configs.perPage, function(err, articles, hasMore) {
        var pageLink;
        if (filterParams.length > 0) {
          locals.action = 'archives';
          if (filterDay) {
            locals.archivesType = 'Daily';
            locals.archivesLabel = new Date(Date.UTC(filterYear, filterMonth - 1, filterDay)).pretty();
          } else if (filterMonth) {
            locals.archivesType = 'Monthly';
            locals.archivesLabel = Date.prototype.months[filterMonth - 1] + ' ' + filterYear;
          } else {
            locals.archivesType = 'Yearly';
            locals.archivesLabel = filterYear;
          }
          locals.title = locals.archivesLabel;
        } else {
          locals.action = 'listing';
        }
        locals.articles = articles;
        locals.page = parseInt(filterPage);
        locals.filter = filterParams;
        locals.paging = {};
        pageLink = function(page) {
          var url;
          url = configs.baseUrl + '/' + filterParams.join('/');
          if (page > 1) {
            url = url + 'page/' + page;
          }
          return url;
        };
        if (locals.page > 1) {
          locals.paging.previous = pageLink(locals.page - 1);
        }
        if (hasMore) {
          locals.paging.next = pageLink(locals.page + 1);
        }
        return listView.render(res, locals, function(err) {
          if (err) {
            return next(new Error(500, err));
          }
        });
      });
    });
    app.get(/^\/([0-9]{4})\/([0-9]{2})\/([0-9]{2})\/(.*)\/?$/, function(req, res, next) {
      return Article.fromFile(configs.articlesDir + '/' + path.normalize(req.params.join('-')) + configs.ext, configs.encoding, function(err, article) {
        var locals;
        if (err) {
          return next(new Error(404, err));
        }
        locals = {
          article: article,
          title: article.title()
        };
        return articleView.render(res, locals, function(err) {
          if (err) {
            return next(new Error(500, err));
          }
        });
      });
    });
    return app.get('/feed.xml', function(req, res, next) {
      return getArticles(null, 1, 25, function(err, articles) {
        var locals;
        if (err) {
          return next(new Error(500, err));
        }
        locals = {
          articles: articles,
          lastBuild: new Date()
        };
        return feedView.partial(locals, function(err, data) {
          if (err) {
            return next(new Error(500, err));
          }
          res.writeHead(200, {
            'content-type': 'text/xml'
          });
          return res.end(data);
        });
      });
    });
  };
};
/*
Module Exports
*/
module.exports.app = app;
